Monolith class

FlutterでのModular Monolith Workspaceの処理をサポートするクラス.

Constructors

Monolith(MonolithOptions options)
factory

Properties

configurations Map<String, dynamic>
monolith.yaml 系ファイルから読み込んだ設定値.
final
hashCode int
The hash code for this object.
no setterinherited
options MonolithOptions
オプション.
final
project DartPackage
ワークスペースのRootパッケージ.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workspace Iterable<DartPackage>
ワークスペースすべてのプロジェクトを列挙する. 最初のプロジェクトは、ワークスペースのルートプロジェクト.
no setter

Methods

each(Future<void> callback(DartPackage pkg)) Future
ワークスペースに含まれるpackageを処理する.
findConfiguration<T>(List<String> path) → T?
指定パスの設定値を取得する. 存在しない場合はnullを返す.
findFromFocusFile(File file) DartPackage?
指定ファイルが含まれるpackageを取得する.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printConfigurations({void print(String msg)?}) → void
設定値を出力する.
relativeDirectory(String path) Directory
ルートプロジェクトからのディレクトリ取得
relativeFile(String path) File
ルートプロジェクトからのファイル取得
require(String name) DartPackage
ワークスペースに含まれるpackageを取得する. 存在しない場合は例外を投げる.
requireConfiguration<T>(List<String> path) → T
指定パスの設定値を取得する.
run<T>(String name, Future<T> callback(DartPackage pkg)) Future<T>
ワークスペースに含まれるpackageを処理する. 指定したpackage名がnullの場合は、ワークスペースのルートプロジェクトを処理する.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited