MonolithOptions class abstract

Available extensions
Annotations
  • @freezed

Constructors

MonolithOptions({File? monolith, ShellRunner? shellRunner, MonolithFileMerger? monolithFileMerger})
const
factory

Properties

copyWith → $MonolithOptionsCopyWith<MonolithOptions>
Create a copy of MonolithOptions with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
monolith File?
monolith.yamlのパス. nullの場合、カレントディレクトリをルートとして monolith.yaml を読み込む.
no setterinherited
monolithFileMerger → MonolithFileMerger?
monolith.yaml 系ファイルをマージするためのインスタンス.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shellRunner → ShellRunner?
シェル実行インスタンス.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_MonolithOptions value)) → TResult

Available on MonolithOptions, provided by the MonolithOptionsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_MonolithOptions value)?) → TResult?

Available on MonolithOptions, provided by the MonolithOptionsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_MonolithOptions value)?, {required TResult orElse()}) → TResult

Available on MonolithOptions, provided by the MonolithOptionsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(File? monolith, ShellRunner? shellRunner, MonolithFileMerger? monolithFileMerger)?, {required TResult orElse()}) → TResult

Available on MonolithOptions, provided by the MonolithOptionsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(File? monolith, ShellRunner? shellRunner, MonolithFileMerger? monolithFileMerger)) → TResult

Available on MonolithOptions, provided by the MonolithOptionsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(File? monolith, ShellRunner? shellRunner, MonolithFileMerger? monolithFileMerger)?) → TResult?

Available on MonolithOptions, provided by the MonolithOptionsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited